# ordo
A lightweight grading tool for nbgallery

## Installation
Install and enable ordo on your Jupyter server

```bash
pip install ordo -U
jupyter nbextension install --py ordo
jupyter nbextension enable ordo --py